@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 # -----------------------------------------------------------------------------
 # Copyright (c) 2011-2017, The BIOM Format Development Team.
 #
@@ -23,7 +22,7 @@ from unittest import TestCase, main
 from shutil import copy
 
 import numpy as np
-import numpy.testing as npt
+import pytest
 
 from biom.cli.table_validator import TableValidator
 from biom.util import HAVE_H5PY
@@ -56,7 +55,7 @@ class TableValidatorTests(TestCase):
         for f in self.to_remove:
             os.remove(f)
 
-    @npt.dec.skipif(HAVE_H5PY is False, msg='H5PY is not installed')
+    @pytest.mark.skipif(HAVE_H5PY is False, reason='H5PY is not installed')
     def test_valid_hdf5_metadata_v210(self):
         exp = {'valid_table': True, 'report_lines': []}
         obs = self.cmd(table=self.hdf5_file_valid,
@@ -66,11 +65,11 @@ class TableValidatorTests(TestCase):
                        format_version='2.1')
         self.assertEqual(obs, exp)
 
-    @npt.dec.skipif(HAVE_H5PY is False, msg='H5PY is not installed')
+    @pytest.mark.skipif(HAVE_H5PY is False, reason='H5PY is not installed')
     def test_valid_hdf5_metadata_v200(self):
         pass  # omitting, not a direct way to test at this time using the repo
 
-    @npt.dec.skipif(HAVE_H5PY is False, msg='H5PY is not installed')
+    @pytest.mark.skipif(HAVE_H5PY is False, reason='H5PY is not installed')
     def test_valid_hdf5(self):
         """Test a valid HDF5 table"""
         exp = {'valid_table': True,
@@ -79,7 +78,7 @@ class TableValidatorTests(TestCase):
         obs = self.cmd(table=self.hdf5_file_valid)
         self.assertEqual(obs, exp)
 
-    @npt.dec.skipif(HAVE_H5PY is False, msg='H5PY is not installed')
+    @pytest.mark.skipif(HAVE_H5PY is False, reason='H5PY is not installed')
     def test_invalid_hdf5(self):
         """Test an invalid HDF5 table"""
         exp = {'valid_table': False,
@@ -290,7 +289,7 @@ class TableValidatorTests(TestCase):
         obs = self.cmd._valid_matrix_element_type(table)
         self.assertTrue(len(obs) == 0)
 
-        table['matrix_element_type'] = u'int'
+        table['matrix_element_type'] = 'int'
         obs = self.cmd._valid_matrix_element_type(table)
         self.assertTrue(len(obs) == 0)
 
@@ -298,7 +297,7 @@ class TableValidatorTests(TestCase):
         obs = self.cmd._valid_matrix_element_type(table)
         self.assertTrue(len(obs) == 0)
 
-        table['matrix_element_type'] = u'float'
+        table['matrix_element_type'] = 'float'
         obs = self.cmd._valid_matrix_element_type(table)
         self.assertTrue(len(obs) == 0)
 
@@ -306,7 +305,7 @@ class TableValidatorTests(TestCase):
         obs = self.cmd._valid_matrix_element_type(table)
         self.assertTrue(len(obs) == 0)
 
-        table['matrix_element_type'] = u'str'
+        table['matrix_element_type'] = 'str'
         obs = self.cmd._valid_matrix_element_type(table)
         self.assertTrue(len(obs) == 0)
 
@@ -314,7 +313,7 @@ class TableValidatorTests(TestCase):
         obs = self.cmd._valid_matrix_element_type(table)
         self.assertTrue(len(obs) > 0)
 
-        table['matrix_element_type'] = u'asd'
+        table['matrix_element_type'] = 'asd'
         obs = self.cmd._valid_matrix_element_type(table)
         self.assertTrue(len(obs) > 0)
 
